@@ -10,7 +10,7 @@ use MooX::Press::Keywords ();
 package MooX::Pression;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001';
+our $VERSION   = '0.002';
 
 use Keyword::Declare;
 use B::Hooks::EndOfScope;
@@ -430,7 +430,7 @@ sub import {
 	
 	# `coerce` keyword
 	#
-	keyword coerce (Block|Identifier|String $from, 'via', Block|Identifier|String $via, Block? $code) {
+	keyword coerce ('from'?, Block|Identifier|String $from, 'via', Block|Identifier|String $via, Block? $code) {
 		if ($from =~ /^\{/) {
 			$from = "scalar(do $from)"
 		}
@@ -549,7 +549,9 @@ MooX::Pression - express yourself through moo
 
 =head1 SYNOPSIS
 
-  use v5.14;
+MyApp.pm
+
+  use v5.18;
   use strict;
   use warnings;
   
@@ -574,17 +576,29 @@ MooX::Pression - express yourself through moo
       method greet (Person *friend, Str *greeting = "Hello") {
         printf("%s, %s!\n", $arg->greeting, $arg->friend->name);
       }
+      
+      coerce from Str via from_string {
+        return $class->new(name => $_);
+      }
     }
   }
-  
+
+my_script.pl
+
+  use v5.18;
+  use strict;
+  use warnings;
+  use MyApp;
   use MyApp::Types qw( is_Person );
   
+  # Create a new MyApp::Person object.
+  #
   my $alice  = MyApp->new_woman("Alice");
-  my $bob    = MyApp->new_man("Bob");
-  
-  $alice->greet(friend => $bob, greeting => 'Hi');
-  
   is_Person($alice) or die;
+  
+  # The string "Bob" will be coerced to a MyApp::Person.
+  #
+  $alice->greet(friend => "Bob", greeting => 'Hi');
 
 =head1 DESCRIPTION
 
@@ -601,7 +615,8 @@ have been amped up.
 It's more opinionated about API design and usage than Moops is, but in
 most cases, it should be fairly easy to port Moops code to MooX::Pression.
 
-MooX::Pression requires Perl 5.14.0 or above.
+MooX::Pression requires Perl 5.18.0 or above. It may work on Perl 5.14.x
+and Perl 5.16.x partly, but there are likely to be issues.
 
 L<MooX::Press> is a less magic version of MooX::Pression and only requires
 Perl 5.8.8 or above.
@@ -843,7 +858,7 @@ Per-package C<begin> overrides the global C<begin>.
 
 =head3 C<< end >>
 
-This code gets run early on in the definition of a class or role.
+This code gets run late in the definition of a class or role.
 
   class Person {
     end {
@@ -894,9 +909,9 @@ possible to quote types as strings, in which case you don't need to have
 pre-declared them.
 
   class Person {
-    has name   ( is => rw,   type => Str, required => true );
-    has age    ( is => rw,   type => Int );
-    has spouse ( is => rw,   type => 'Person' );
+    has name   ( type => Str, required => true );
+    has age    ( type => Int );
+    has spouse ( type => 'Person' );
     has kids   (
       is      => lazy,
       type    => 'ArrayRef[Person]',
@@ -912,10 +927,17 @@ C<< does => 'SomeRole' >> to force strings to be treated as class names
 or role names instead of type names.
 
   class Person {
-    has name   ( is => rw,   type => Str, required => true );
-    has age    ( is => rw,   type => Int );
-    has spouse ( is => rw,   isa  => 'Person' );
-    has pet    ( is => rw,   isa  => '::Animal' );   # no prefix
+    has name   ( type => Str, required => true );
+    has age    ( type => Int );
+    has spouse ( isa  => 'Person' );
+    has pet    ( isa  => '::Animal' );   # no prefix
+  }
+
+For enumerations, you can define them like this:
+
+  class Person {
+    ...;
+    has status ( enum => ['alive', 'dead', 'undead'] );
   }
 
 It is possible to add hints to the name as a shortcut for common
@@ -1294,7 +1316,7 @@ like saying C<< via new >>.
     has name   ( type => Str, required => true );
     has gender ( type => Str );
     
-    coerce Str via from_string {
+    coerce from Str via from_string {
       $class->new(name => $_);
     }
   }
@@ -1324,12 +1346,19 @@ can define a coercion as a normal method first:
       $class->new(name => $name);
     }
     
-    coerce Str via from_string;
+    coerce from Str via from_string;
   }
 
 In both cases, a C<< MyApp::Person->from_string >> method is generated
 which can be called to manually coerce a string into a person object.
 
+They keyword C<< from >> is technically optional, but does make the
+statement more readable.
+
+  coerce Str via from_string {      # this works
+    $class->new(name => $_);
+  }
+
 =head3 C<< version >>
 
   class Person {
